#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _qt qt6%{nil}
%if "%{_qt}" == ""
ExclusiveArch:  do_not_build
%endif
%if "%{_qt}" == "qt5"
%define mname qscintilla-qt5
%define distname QScintilla
%define _qmake %qmake5
%define _qmake_build %{__make} %{?_smp_mflags} VERBOSE=1
%define _qmake_install %qmake5_install
%define _qt_datadir %_libqt5_datadir
%define _qt_archdatadir %_libqt5_archdatadir
%define pyqt_mname PyQt5
%define psuffix -qt5
%endif
%if "%{_qt}" == "qt6"
%define mname PyQt6-QScintilla
%define distname PyQt6_QScintilla
%define _qmake %qmake6
%define _qmake_build %qmake6_build
%define _qmake_install %qmake6_install
%define _qt_datadir %_qt6_datadir
%define _qt_archdatadir %_qt6_archdatadir
%define pyqt_mname PyQt6
%define pyqt_build_for_qt6 1
%endif

# PyQt5 built against SIP v4 is not compatible with this version of QScintilla.
# if your distro target still uses the SIPv4 built PyQt5, disable python bindings
%bcond_without python

%define skip_python2 1
%define debug_package_requires libqscintilla2_qt5-%{sonum} = %{version}-%{release}
%define sonum   15
Name:           qscintilla%{?psuffix}
Version:        2.13.4
Release:        1.4
Summary:        C++ Editor Class Library
License:        GPL-3.0-only
URL:            https://www.riverbankcomputing.com/software/qscintilla
Source:         https://www.riverbankcomputing.com/static/Downloads/QScintilla/%{version}/QScintilla_src-%{version}.tar.gz
Source99:       qscintilla-rpmlintrc
BuildRequires:  pkgconfig
%if "%{_qt}" == "qt5"
BuildRequires:  pkgconfig(Qt5Core) > 5.11.0
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
%endif
%if "%{_qt}" == "qt6"
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Designer)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Widgets)
%endif
%if "%{?psuffix}" != ""
Provides:       qscintilla2_%{_qt} = %{version}-%{release}
Obsoletes:      qscintilla2_%{_qt} < %{version}-%{release}
%endif
%if %{with python}
BuildRequires:  %{python_module %{pyqt_mname}-devel}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pyqt-builder >= 1.6}
BuildRequires:  %{python_module sip-devel >= 6.0.2}
BuildRequires:  python-pyqt-rpm-macros
BuildRequires:  python-rpm-macros >= 20210131
%define python_subpackage_only 1
%python_subpackages
%endif

%description
QScintilla is a Qt port of Neil Hodgson's Scintilla C++ editor class.

This is a Qt port from the original Scintilla class for %{_qt}
(http://www.scintilla.org/).

%package %{_qt}
Summary:        C++ Editor Class Library
Provides:       qscintilla2_%{_qt} = %{version}-%{release}
Obsoletes:      qscintilla2_%{_qt} < %{version}-%{release}
%if "%{_qt}" == "qt5"
# Translations were in the library package in the past
Conflicts:      libqscintilla2_qt5-13
%endif

%description %{_qt}
QScintilla is a Qt port of Neil Hodgson's Scintilla C++ editor class.

This is a Qt port from the original Scintilla class for %{_qt}
(http://www.scintilla.org/).

%package -n libqscintilla2_%{_qt}-%{sonum}
Summary:        C++ Editor Class Library
Requires:       qscintilla2_%{_qt} = %{version}
Provides:       libqscintilla2-%{_qt}-%{sonum} = %{version}
Obsoletes:      libqscintilla2-%{_qt}-%{sonum} < %{version}

%description -n libqscintilla2_%{_qt}-%{sonum}
QScintilla is a Qt port of Neil Hodgson's Scintilla C++ editor class.

This is a Qt port from the original Scintilla class
(http://www.scintilla.org/).

%package -n qscintilla-%{_qt}-devel
Summary:        C++ Editor Class Library Development Files
Requires:       libqscintilla2-%{_qt}-%{sonum} = %{version}
%if "%{_qt}" == "qt5"
Requires:       pkgconfig(Qt5Core)
Requires:       pkgconfig(Qt5PrintSupport)
Requires:       pkgconfig(Qt5Widgets)
%endif
%if "%{_qt}" == "qt6"
Requires:       cmake(Qt6Core)
Requires:       cmake(Qt6PrintSupport)
Requires:       cmake(Qt6Widgets)
%endif
Provides:       libqscintilla-%{_qt}-devel = %{version}
Obsoletes:      libqscintilla-%{_qt}-devel < %{version}
Provides:       libqscintilla_%{_qt}-devel = %{version}
Obsoletes:      libqscintilla_%{_qt}-devel < %{version}
Provides:       libqscintilla2_%{_qt}-devel = %{version}
Obsoletes:      libqscintilla2_%{_qt}-devel < %{version}

%description -n qscintilla-%{_qt}-devel
QScintilla is a Qt port of Neil Hodgson's Scintilla C++ editor class.

This is a Qt port from the original Scintilla class
(http://www.scintilla.org/).

This package contains the development files for %{name}-%{_qt}.

%package -n python-%{mname}
Summary:        Python bindings for QScintilla for %{pyqt_mname}
%if "%{_qt}" == "qt5"
Provides:       python-qscintilla-qt5-sip = %{version}-%{release}
Obsoletes:      python-qscintilla-qt5-sip < %{version}-%{release}
%endif
%if "%{_qt}" == "qt6"
Provides:       python-qscintilla-qt6 = %{version}-%{release}
%endif
Requires:       python-%{pyqt_mname}

%description -n python-%{mname}
QScintilla is a Qt port of Neil Hodgson's Scintilla C++ editor class.

This is a Qt port from the original Scintilla class
(http://www.scintilla.org/).

This package provides the Python bindings for QScintilla for %{pyqt_mname}.

%prep
%setup -q -n QScintilla_src-%{version}

%build
# build library
pushd src
%_qmake CONFIG+=c++11
%_qmake_build
popd

# build designer plugin
pushd designer
echo "LIBS += -L../src -lqscintilla2_%{_qt}" >>  designer.pro
echo "INCLUDEPATH += -L ../src" >>  designer.pro
%_qmake CONFIG+=c++11
%_qmake_build
popd

%if %{with python}
# build Python bindings
pushd Python
cp pyproject-%{_qt}.toml pyproject.toml
%{pyqt_build -s %{quote:--qsci-features-dir=../src/features \
                        --qsci-include-dir=../src \
                        --qsci-library-dir=../src}}
popd
%endif

%install
pushd src
%_qmake_install
popd
pushd designer
%_qmake_install
popd
%if %{with python}
pushd Python
%pyqt_install
popd
%endif

%post -n libqscintilla2_%{_qt}-%{sonum} -p /sbin/ldconfig
%postun -n libqscintilla2_%{_qt}-%{sonum} -p /sbin/ldconfig

%files %{!?psuffix:%_qt}
%license LICENSE
%doc NEWS
%{_qt_datadir}/qsci/
%exclude %{_qt_datadir}/qsci/api/python_*
%{_qt_datadir}/translations/
%dir %{_qt_archdatadir}/plugins/designer
%{_qt_archdatadir}/plugins/designer/libqscintillaplugin.so

%files -n libqscintilla2_%{_qt}-%{sonum}
%license LICENSE
%{_libdir}/libqscintilla2_%{_qt}.so.%{sonum}*

%files -n qscintilla-%{_qt}-devel
%{_includedir}/%{_qt}/Qsci/
%{_libdir}/libqscintilla2_%{_qt}.so
%{_qt_archdatadir}/mkspecs/features/qscintilla2.prf

%if %{with python}
%files %{python_files %{mname}}
%license LICENSE
%doc NEWS
%dir %{python_sitearch}/%{pyqt_mname}/
%{python_sitearch}/%{pyqt_mname}/Qsci.*
%dir %{python_sitearch}/%{pyqt_mname}/bindings
%{python_sitearch}/%{pyqt_mname}/bindings/Qsci
%{python_sitearch}/%{distname}-%{version}.dist-info/
%{_qt_datadir}/qsci/api/python_%{python_bin_suffix}/
%endif

%changelog
* Sun Jan 29 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.13.4
  * Added the .api files for Python v3.10 and v3.11.
  * Bug fixes
* Sun May 29 2022 Dirk Müller <dmueller@suse.com>
- update to 2.13.3:
  * Bug fixes.
* Fri Feb  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Conflict libqscintilla2_qt5-13 to avoid file conflict
* Sun Oct 24 2021 Ben Greiner <code@bnavigator.de>
- Update to version 2.13.1
  * Documented how to build for multiple architectures on macOS.
  * Bug fixes.
* Tue Jul  6 2021 Ben Greiner <code@bnavigator.de>
- Fix the python3Y-qscintilla-qt5-sip obsoletion.
* Mon Jul  5 2021 Ben Greiner <code@bnavigator.de>
- Move the main package to subpackage declaration and use the qt6
  build for the plain qscintilla source package name (make
  factory-auto bot happy)
* Sat Jul  3 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 2.13.0
  * Added the QsciPrinter::printRange() overload that uses a
    supplied QPainter to render the pages.
  * Improved the appearence of the auto-completion popup.
  * Bug fixes.
* Thu Mar 11 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 2.12.1
  * Packaging bug fixes.
* Thu Feb 25 2021 Ben Greiner <code@bnavigator.de>
- Update to Version 2.12.0
  * Added support for Qt6.
  * Removed support for Qt4 and Qt5 earlier than v5.11.0.
- rename source package to qscintilla
  * build for Qt5 and Qt6 in multibuild
- SIP v4 is no longer supported. Even SIPv5 has a bug that prevents
  a build with sip-build. Use SIPv6.
* Tue Nov 24 2020 Benjamin Greiner <code@bnavigator.de>
- Update to Version 2.11.6
  * Added the --qsci-translations-dir option to sip-wheel.
  * Added the .api file for Python v3.9.
  * Build system changes.
  * Bug fixes.
* Thu Nov  5 2020 Benjamin Greiner <code@bnavigator.de>
- Dropped patch: python-config.diff -- not needed even for the SIP4
  builds
* Wed Sep  9 2020 Benjamin Greiner <code@bnavigator.de>
- Use sip5 for python package where available
- remove the separate python-qscintilla-qt5 specfile and make
  multibuild instead
* Mon Aug 31 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 2.11.5
  * The bundled .api files are now included in Python wheels if the
    QScintilla.api file is enabled.
  * Bug fixes.
- Tumbleweed skips python2 builds automatically no need to
  hack python_module
* Fri Mar 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Stop building the python2 package for openSUSE Tumbleweed.
* Wed Nov 13 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.11.3
  * Added support for SIP v5.
  * On macOS the install name of the C++ library is now relative to @rpath.
* Thu Aug 29 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Co-own designer directory in Qt's plugins directory, as libqt5-qttools
  is no longer pulled in implicitly.
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.11.2
  * QsciScintilla::clear() now clears the undo history
  * QsciScintilla::findMatchingBrace() is now part of the public API.
  * Added the .api file for Python v3.8.
* Tue Apr 16 2019 Christophe Giboudeaux <christophe@krop.fr>
- Move some files out of the -devel package.
* Fri Apr  5 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the lost changelog entries back.
* Tue Apr  2 2019 Christophe Giboudeaux <christophe@krop.fr>
- Drop qscintilla-qt4 and python-qscintilla-qt4.
- Drop qscintilla-qt4.diff. No longer needed.
- Re-sync the changelog files.
* Fri Feb 15 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.11.1
  * Details at https://www.riverbankcomputing.com/static/Downloads/QScintilla/ChangeLog
- Refresh python-config.diff
- Drop reproducible.patch. Merged upstream
* Wed Nov  7 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort input file list to make package
  build reproducible (boo#1041090)
* Sun Oct 21 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.10.8:
  * Refactored the accessibility support
* Mon Jul  2 2018 christophe@krop.fr
- Update to 2.10.7:
  * Added the QsciLexerEDIFACT class.
  * Added setStyle() to QsciStyle.
  * Control-wheel scroll will now zoom in and out of the document.
  * Buffered drawing is now disabled by default.
- Refresh patches
* Tue Apr 17 2018 lbeltrame@kde.org
- Remove source URL for now to work around SourceForge's unreliable
  mirroring
* Tue Apr 17 2018 termim@gmail.com
- Update to version 2.10.4
  * Bug fixes.
- Update to version 2.10.3
  * Added accessibility support.
  * Added the API file for Python v3.7.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to version 2.10.2
  * Added setScrollWidth() , scrollWidth, setScrollWidthTracking()
    and scrollWidthTracking() to QsciScintilla.
  * Bug fixes.
  version v2.10.1
  * Added previously internal lexer methods to the Python bindings.
* Thu May 25 2017 toddrme2178@gmail.com
- Fix python Requires, Provides, and Obsoletes.
  This pulls in proper dependencies and avoids conflicts.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Add qt4 versions as subpackages.
- Rename qt4 versions to use "_qt4" suffix.
- Use new qt-version-specific names provided by qscintilla 2.10
  rather than manually adding a "-qt5" suffix.
- Use "_qt5" suffix instead of "_qt4" for library packages to
  conform to upstream library naming.
* Sat Apr  1 2017 hpj@urpla.net
- force -std=c++11 to compile with Leap 42.1
* Sun Mar 12 2017 toddrme2178@gmail.com
- Implement single-spec version
* Wed Mar  1 2017 termim@gmail.com
- Update to 2.10
  - Based on Scintilla v3.7.2.
  - Added the QsciLexerJSON class.
  - Added the QsciLexerMarkdown class.
  - Added replaceHorizontalScrollBar() and replaceVerticalScrollBar() to
    QsciScintillaBase.
  - Added bytes() and a corresponding text() overload to QsciScintilla.
  - Added EdgeMultipleLines to QsciScintilla::EdgeMode.
  - Added addEdgeColumn() and clearEdgeColumns() to QsciScintilla.
  - Added the marginRightClicked() signal to QsciScintilla.
  - Added SymbolMarginColor to QsciScintilla::MarginType.
  - Added setMarginBackgroundColor() and marginBackgroundColor() to
    QsciScintilla.
  - Added setMargins() and margins() to QsciScintilla.
  - Added TriangleIndicator and TriangleCharacterIndicator to
    QsciScintilla::IndicatorStyle.
  - Added WsVisibleOnlyInIndent to QsciScintilla::WhitespaceVisibility.
  - Added TabDrawMode, setTabDrawMode() and tabDrawMode() to QsciScintilla.
  - Added InstanceProperty to QsciLexerCoffeeScript.
  - Added EDGE_MULTILINE to QsciScintillaBase.
  - Added INDIC_POINT and INDIC_POINTCHARACTER to QsciScintillaBase.
  - Added SC_AC_FILLUP, SC_AC_DOUBLECLICK, SC_AC_TAB, SC_AC_NEWLINE and
    SC_AC_COMMAND to QsciScintillaBase.
  - Added SC_CASE_CAMEL to QsciScintillaBase.
  - Added SC_CHARSET_CYRILLIC and SC_CHARSET_OEM866 to QsciScintillaBase.
  - Added SC_FOLDDISPLAYTEXT_HIDDEN, SC_FOLDDISPLAYTEXT_STANDARD and
    SC_FOLDDISPLAYTEXT_BOXED to QsciScintillaBase.
  - Added SC_IDLESTYLING_NONE, SC_IDLESTYLING_TOVISIBLE,
    SC_IDLESTYLING_AFTERVISIBLE and SC_IDLESTYLING_ALL to QsciScintillaBase.
  - Added SC_MARGIN_COLOUR to QsciScintillaBase.
  - Added SC_POPUP_NEVER, SC_POPUP_ALL and SC_POPUP_TEXT to QsciScintillaBase.
  - Added SCI_FOLDDISPLAYTEXTSETSTYLE and SCI_TOGGLEFOLDSHOWTEXT to
    QsciScintillaBase.
  - Added SCI_GETIDLESTYLING and SCI_SETIDLESTYLING to QsciScintillaBase.
  - Added SCI_GETMARGINBACKN and SCI_SETMARGINBACKN to QsciScintillaBase.
  - Added SCI_GETMARGINS and SCI_SETMARGINS to QsciScintillaBase.
  - Added SCI_GETMOUSEWHEELCAPTURES and SCI_SETMOUSEWHEELCAPTURES to
    QsciScintillaBase.
  - Added SCI_GETTABDRAWMODE and SCI_SETTABDRAWMODE to QsciScintillaBase.
  - Added SCI_ISRANGEWORD to QsciScintillaBase.
  - Added SCI_MULTIEDGEADDLINE and SCI_MULTIEDGECLEARALL to QsciScintillaBase.
  - Added SCI_MULTIPLESELECTADDNEXT and SCI_MULTIPLESELECTADDEACH to
    QsciScintillaBase.
  - Added SCI_TARGETWHOLEDOCUMENT to QsciScintillaBase.
  - Added SCLEX_JSON and SCLEX_EDIFACT to QsciScintillaBase.
  - Added SCTD_LONGARROW and SCTD_STRIKEOUT to QsciScintillaBase.
  - Added SCVS_NOWRAPLINESTART to QsciScintillaBase.
  - Added SCWS_VISIBLEONLYININDENT to QsciScintillaBase.
  - Added STYLE_FOLDDISPLAYTEXT to QsciScintillaBase.
  - Added the SCN_AUTOCCOMPLETED() signal to QsciScintillaBase.
  - Added the overloaded SCN_AUTOCSELECTION() and SCN_USERLISTSELECTION()
    signals to QsciScintillaBase.
  - Added the SCN_MARGINRIGHTCLICK() signal to QsciScintillaBase.
  - Renamed SCI_GETTARGETRANGE to SCI_GETTARGETTEXT in QsciScintillaBase.
  - Removed SCI_GETKEYSUNICODE and SCI_SETKEYSUNICODE to QsciScintillaBase.
  - The autoCompletionFillups(), autoCompletionWordSeparators(), blockEnd(),
    blockLookback(), blockStart(), blockStartKeyword(), braceStyle(),
    caseSensitive(), indentationGuideView() and defaultStyle() methods of
    QsciLexer are no longer marked as internal and are exposed to Python so
    that they may be used by QsciLexerCustom sub-classes.
  - The name of the library has been changed to include the major version
    number of the version of Qt it is built against (ie. 4 or 5).
* Tue Jan  3 2017 termim@gmail.com
- Update to 2.9.4
  - Added the .api file for Python v3.6.
  - Bug fixes.
* Tue Jul 26 2016 termim@gmail.com
- Update to 2.9.3
  - Bug fixes
- Update to 2.9.2
  - Added support for a PEP 484 stub file for the Python extension module.
* Fri Oct 30 2015 termim@gmail.com
- Update to 2.9.1
  - This is primarily a bug-fix release.
* Fri Aug 14 2015 termim@gmail.com
- change required sip version to 4.16.9
* Sat Jul 18 2015 termim@gmail.com
- Update to 2.9
  - Based on Scintilla v3.5.4.
  - Added UserLiteral, InactiveUserLiteral, TaskMarker, InactiveTaskMarker,
    EscapeSequence, InactiveEscapeSequence, setHighlightBackQuotedStrings(),
    highlightBackQuotedStrings(), setHighlightEscapeSequences(),
    highlightEscapeSequences(), setVerbatimStringEscapeSequencesAllowed() and
    verbatimStringEscapeSequencesAllowed() to QsciLexerCPP.
  - Added CommentKeyword, DeclareInputPort, DeclareOutputPort,
    DeclareInputOutputPort, PortConnection and the inactive versions of all
    styles to QsciLexerVerilog.
  - Added CommentBlock to QsciLexerVHDL.
  - Added AnnotationIndented to QsciScintilla::AnnotationDisplay.
  - Added FullBoxIndicator, ThickCompositionIndicator, ThinCompositionIndicator
    and TextColorIndicator to QsciScintilla::IndicatorStyle.
  - Added setIndicatorHoverForegroundColor() and setIndicatorHoverStyle() to
    QsciScintilla.
  - Added Bookmark to QsciScintilla::MarkerSymbol.
  - Added WrapWhitespace to QsciScintilla::WrapMode.
  - Added SCLEX_AS, SCLEX_BIBTEX, SCLEX_DMAP, SCLEX_DMIS, SCLEX_IHEX,
    SCLEX_REGISTRY, SCLEX_SREC and SCLEX_TEHEX to QsciScintillaBase.
  - Added SCI_CHANGEINSERTION to QsciScintillaBase.
  - Added SCI_CLEARTABSTOPS, SCI_ADDTABSTOP and SCI_GETNEXTTABSTOP to
    QsciScintillaBase.
  - Added SCI_GETIMEINTERACTION, SCI_SETIMEINTERACTION, SC_IME_WINDOWED and
    SC_IME_INLINE to QsciScintillaBase.
  - Added SC_MARK_BOOKMARK to QsciScintillaBase.
  - Added INDIC_COMPOSITIONTHIN, INDIC_FULLBOX, INDIC_TEXTFORE, INDIC_IME,
    INDIC_IME_MAX, SC_INDICVALUEBIT, SC_INDICVALUEMASK,
    SC_INDICFLAG_VALUEBEFORE, SCI_INDICSETHOVERSTYLE, SCI_INDICGETHOVERSTYLE,
    SCI_INDICSETHOVERFORE, SCI_INDICGETHOVERFORE, SCI_INDICSETFLAGS and
    SCI_INDICGETFLAGS to QsciScintillaBase.
  - Added SCI_SETTARGETRANGE and SCI_GETTARGETRANGE to QsciScintillaBase.
  - Added SCFIND_CXX11REGEX to QsciScintillaBase.
  - Added SCI_CALLTIPSETPOSSTART to QsciScintillaBase.
  - Added SC_FOLDFLAG_LINESTATE to QsciScintillaBase.
  - Added SC_WRAP_WHITESPACE to QsciScintillaBase.
  - Added SC_PHASES_ONE, SC_PHASES_TWO, SC_PHASES_MULTIPLE, SCI_GETPHASESDRAW
    and SCI_SETPHASESDRAW to QsciScintillaBase.
  - Added SC_STATUS_OK, SC_STATUS_FAILURE, SC_STATUS_BADALLOC,
    SC_STATUS_WARN_START and SC_STATUS_WARNREGEX to QsciScintillaBase.
  - Added SC_MULTIAUTOC_ONCE, SC_MULTIAUTOC_EACH, SCI_AUTOCSETMULTI and
    SCI_AUTOCGETMULTI to QsciScintillaBase.
  - Added ANNOTATION_INDENTED to QsciScintillaBase.
  - Added SCI_DROPSELECTIONN to QsciScintillaBase.
  - Added SC_TECHNOLOGY_DIRECTWRITERETAIN and SC_TECHNOLOGY_DIRECTWRITEDC to
    QsciScintillaBase.
  - Added SC_LINE_END_TYPE_DEFAULT, SC_LINE_END_TYPE_UNICODE,
    SCI_GETLINEENDTYPESSUPPORTED, SCI_SETLINEENDTYPESALLOWED,
    SCI_GETLINEENDTYPESALLOWED and SCI_GETLINEENDTYPESACTIVE to
    QsciScintillaBase.
  - Added SCI_ALLOCATESUBSTYLES, SCI_GETSUBSTYLESSTART, SCI_GETSUBSTYLESLENGTH,
    SCI_GETSTYLEFROMSUBSTYLE, SCI_GETPRIMARYSTYLEFROMSTYLE, SCI_FREESUBSTYLES,
    SCI_SETIDENTIFIERS, SCI_DISTANCETOSECONDARYSTYLES and SCI_GETSUBSTYLEBASES
    to QsciScintillaBase.
  - Added SC_MOD_INSERTCHECK and SC_MOD_CHANGETABSTOPS to QsciScintillaBase.
  - Qt v3 and PyQt v3 are no longer supported.
* Sat Oct 11 2014 termim@gmail.com
- build for Qt5
* Sat Oct 11 2014 termim@gmail.com
- Update to 2.8.4
  - This is a minor functional release include the addition of some hotspot
    related functions to the high-level API.
  - run spec-cleaner
* Thu Jul 31 2014 toddrme2178@gmail.com
- Run spec file through spec-cleaner
- Various spec file cleanups
* Thu Jul 31 2014 termim@gmail.com
- Update to v2.8.3
  - Added the QsciLexerCoffeeScript class.
  - Font sizes are now handled as floating point values rather than integers.
  - Bug fixes.
* Thu May 29 2014 termim@gmail.com
- Update to v2.8.2
  - Added the QsciLexerAVS class.
  - Added the QsciLexerPO class.
  - Added the --sysroot, --no-sip-files and --no-qsci-api options to the Python
    bindings' configure.py.
  - Cross-compilation (specifically to iOS and Android) is now supported.
  - configure.py has been refactored and relicensed so that it can be used as a
    template for wrapping other bindings.
  - Bug fixes.
* Sun Mar 23 2014 tittiatcoke@gmail.com
- Update to v2.8.1
  - Added support for iOS and Android.
  - Added support for retina displays.
  - A qscintilla2.prf file is installed so that application .pro files only
    need to add CONFIG += qscintilla2.
  - Updated the keywords recognised by the Octave lexer.
  - Bug fixes.
- Rebase qscintilla.diff for the new release
* Thu Nov 14 2013 termim@gmail.com
- update to v2.8:
  - Based on Scintilla v3.3.6.
  - Added the SCN_FOCUSIN() and SCN_FOCUSOUT() signals to QsciScintillaBase.
  - Added PreProcessorCommentLineDoc and InactivePreProcessorCommentLineDoc to
    QsciLexerCPP.
  - Added SCLEX_LITERATEHASKELL, SCLEX_KVIRC, SCLEX_RUST and SCLEX_STTXT to
    QsciScintillaBase.
  - Added ThickCompositionIndicator to QsciScintilla::IndicatorStyle.
  - Added INDIC_COMPOSITIONTHICK to QsciScintillaBase.
  - Added SC_FOLDACTION_CONTRACT, SC_FOLDACTION_EXPAND and SC_FOLDACTION_TOGGLE
    to QsciScintillaBase.
  - Added SCI_FOLDLINE, SCI_FOLDCHILDREN, SCI_EXPANDCHILDREN and SCI_FOLDALL to
    QsciScintillaBase.
  - Added SC_AUTOMATICFOLD_SHOW, SC_AUTOMATICFOLD_CLICK and
    SC_AUTOMATICFOLD_CHANGE to QsciScintillaBase.
  - Added SCI_SETAUTOMATICFOLD and SCI_GETAUTOMATICFOLD to QsciScintillaBase.
  - Added SC_ORDER_PRESORTED, SC_ORDER_PERFORMSORT and SC_ORDER_CUSTOM to
    QsciScintillaBase.
  - Added SCI_AUTOCSETORDER and SCI_AUTOCGETORDER to QsciScintillaBase.
  - Added SCI_POSITIONRELATIVE to QsciScintillaBase.
  - Added SCI_RELEASEALLEXTENDEDSTYLES and SCI_ALLOCATEEXTENDEDSTYLES to
    QsciScintillaBase.
  - Added SCI_SCROLLRANGE to QsciScintillaBase.
  - Added SCI_SETCARETLINEVISIBLEALWAYS and SCI_GETCARETLINEVISIBLEALWAYS to
    QsciScintillaBase.
  - Added SCI_SETMOUSESELECTIONRECTANGULARSWITCH and
    SCI_GETMOUSESELECTIONRECTANGULARSWITCH to QsciScintillaBase.
  - Added SCI_SETREPRESENTATION, SCI_GETREPRESENTATION and
    SCI_CLEARREPRESENTATION to QsciScintillaBase.
  - Input methods are now properly supported.
* Wed Jun 19 2013 dmueller@suse.com
- update to 2.7.2:
  - The build script for the Python bindings now has a --pyqt argument for
    specifying PyQt4 or PyQt5.
  - The default EOL mode on OS/X is now EolUnix.
  - Bug fixes.
* Fri Apr 12 2013 termim@gmail.com
- update to 2.7.1
  - v2.7.1 1st March 2013
  - Added support for the final release of Qt v5.
  - The build script for the Python bindings should now work with SIP v5.
  - Bug fixes.
  - v2.7 8th December 2012
  - Based on Scintilla v3.23.
  - Added support for Qt v5-rc1.
  - Added HashQuotedString, InactiveHashQuotedString, PreProcessorComment,
    InactivePreProcessorComment, setHighlightHashQuotedStrings() and
    highlightHashQuotedStrings() to QsciLexerCpp.
  - Added Variable, setHSSLanguage(), HSSLanguage(), setLessLanguage(),
    LessLanguage(), setSCCSLanguage() and SCCSLanguage() to QsciLexerCSS.
  - Added setOverwriteMode() and overwriteMode() to QsciScintilla.
  - Added wordAtLineIndex() to QsciScintilla.
  - Added findFirstInSelection() to QsciScintilla.
  - Added CallTipsPosition, callTipsPosition() and setCallTipsPosition() to
    QsciScintilla.
  - Added WrapFlagInMargin to QsciScintilla::WrapVisualFlag.
  - Added SquigglePixmapIndicator to QsciScintilla::IndicatorStyle.
  - The weight of a font (rather than whether it is just bold or not) is now
    respected.
  - Added SCLEX_AVS, SCLEX_COFFEESCRIPT, SCLEX_ECL, SCLEX_OSCRIPT,
    SCLEX_TCMD and SCLEX_VISUALPROLOG to QsciScintillaBase.
  - Added SC_CASEINSENSITIVEBEHAVIOUR_IGNORECASE and
    SC_CASEINSENSITIVEBEHAVIOUR_RESPECTCASE to QsciScintillaBase.
  - Added SC_FONT_SIZE_MULTIPLIER to QsciScintillaBase.
  - Added SC_WEIGHT_NORMAL, SC_WEIGHT_SEMIBOLD and SC_WEIGHT_BOLD to
    QsciScintillaBase.
  - Added SC_WRAPVISUALFLAG_MARGIN to QsciScintillaBase.
  - Added INDIC_SQUIGGLEPIXMAP to QsciScintillaBase.
  - Added SCI_AUTOCSETCASEINSENSITIVEBEHAVIOUR,
    SCI_AUTOCGETCASEINSENSITIVEBEHAVIOUR, SCI_CALLTIPSETPOSITION,
    SCI_COUNTCHARACTERS, SCI_CREATELOADER, SCI_DELETERANGE,
    SCI_FINDINDICATORFLASH, SCI_FINDINDICATORHIDE, SCI_FINDINDICATORSHOW,
    SCI_GETALLLINESVISIBLE, SCI_GETGAPPOSITION, SCI_GETPUNCTUATIONCHARS,
    SCI_GETRANGEPOINTER, SCI_GETSELECTIONEMPTY, SCI_GETTECHNOLOGY,
    SCI_GETWHITESPACECHARS, SCI_GETWORDCHARS, SCI_RGBAIMAGESETSCALE,
    SCI_SETPUNCTUATIONCHARS, SCI_SETTECHNOLOGY, SCI_STYLESETSIZEFRACTIONAL,
    SCI_STYLEGETSIZEFRACTIONAL, SCI_STYLESETWEIGHT and SCI_STYLEGETWEIGHT to
    QsciScintillaBase.
  - Removed SCI_GETUSEPALETTE and SCI_SETUSEPALETTE from QsciScintillaBase.
  - Bug fixes.
* Thu Jul  5 2012 dmueller@suse.com
- link .changes files for python/3-qscintilla to qscintilla.changes
- update to 2.6.2:
  * Added support for Qt v5.
  * QsciLexer::wordCharacters() is now part of the public API.
  * Bug fixes.
* Mon Feb 27 2012 dmueller@suse.de
- update to 2.6.1:
  - Mainly a bugfix release
* Sun Feb  5 2012 termim@gmail.com
- update to 2.6:
  - based on Scintilla v2.29.
  - improved support for rebinding keys to commands
  - native key bindings under OS/X.
- remove Qt3 support (it does not compile with current Qt3 packages)
* Wed Nov 23 2011 termim@gmail.com
- build QScintilla plugin for QT4 Designer
* Mon Aug 15 2011 termim@gmail.com
- update to 2.5.1:
  - based on Scintilla v2.25
* Wed Sep  1 2010 dmueller@suse.de
- update to 2.4.5:
  - A bug fix release.
  - Added the canInsertFromMimeData(), fromMimeData() and toMimeData() methods
    to QsciScintillaBase.
  - QsciScintilla::markerDefine() now allows existing markers to be redefined.
* Tue Apr 20 2010 dmueller@suse.de
- fix build
* Sun Apr 11 2010 beineri@opensuse.org
- update to 2.4.3 release:
  * Added clearFolds() to QsciScintilla.
  * Updated Spanish translations from Jaime Seuma.
  * Fixed compilation problems with Qt v3 and Qt v4 prior to v4.5.
  * Added the QsciLexerSpice and QsciLexerVerilog classes.
  * Significant performance improvements when handling long lines.
  * The Python bindings include automatically generated docstrings
    by default.
  * Added an API file for Python v3.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Jul 10 2009 beineri@opensuse.org
- update build requires after python-sip package split
* Mon Jun  8 2009 beineri@opensuse.org
- update to 2.4 release:
  * support for annotations, margin text
  * ability to write new language lexers
* Tue May 26 2009 dmueller@suse.de
- update to 2.4-snapshot-20090525:
  - Based on Scintilla v1.78.
  - Added the QsciLexerCustom, QsciStyle and QsciStyledText classes.
  - Added annotate(), annotation(), clearAnnotations(), setAnnotationDisplay()
    and annotationDisplay() to QsciScintilla.
  - Added setMarginText(), clearMarginText(), setMarginType() and marginType()
    to QsciScintilla.
  - Added QsciLexer::lexerId() so that container lexers can be implemented.
  - Added editor() and styleBitsNeeded() to QsciLexer.
  - Added setDollarsAllowed() and dollarsAllowed() to QsciLexerCPP.
  - Added setFoldScriptComments(), foldScriptComments(),
    setFoldScriptHeredocs() and foldScriptHeredocs() to QsciLexerHTML.
  - Added setSmartHighlighting() and smartHighlighting() to QsciLexerPascal.
    (Note that the Scintilla Pascal lexer has changed so that any saved colour
    and font settings will not be properly restored.)
  - Added setFoldPackages(), foldPackages(), setFoldPODBlocks() and
    foldPODBlocks() to QsciLexerPerl.
  - Added setV2UnicodeAllowed(), v2UnicodeAllowed(), setV3BinaryOctalAllowed(),
    v3BinaryOctalAllowed(), setV3BytesAllowed and v3BytesAllowed() to
    QsciLexerPython.
  - Added setScriptsStyled() and scriptsStyled() to QsciLexerXML.
  - Added Spanish translations from Jaime Seuma.
* Sat Dec  6 2008 dmueller@suse.de
- update to 2.3.2:
  Added the read() and write() methods to QsciScintilla in anticipation of PyQt
  dropping support for QStrings.  This will allow file to be read and written
  while keeping the number of conversions to the minimum.
* Wed Oct 22 2008 stbinner@suse.de
- debug_package_requires depend also on %%release
* Fri Oct 10 2008 dmueller@suse.de
- update to 2.3 (bnc#432385):
  * Licensing update: Dual licensed GPLv2/v3
  * The new QsciAbstractAPIs class allows applications to replace the default
    implementation of the language APIs used for auto-completion lists and call
    tips.
  * Added QsciScintilla::apiContext() to allow applications to determine the
    context used for auto-completion and call tips.
  * Added the QsciLexerFortran, QsciLexerFortran77, QsciLexerPascal,
    QsciLexerPostScript, QsciLexerTCL, QsciLexerXML and QsciLexerYAML classes.
  * QsciScintilla::setFolding() will now accept an optional margin number.
  * A lexer's default colour, paper and font are now written to and read from
    the settings.
  * Windows64 is now supported.
  * The signature of the QsciScintillaBase::SCN_MACRORECORD() signal has
    changed slightly.
* Mon Sep  3 2007 dmueller@suse.de
- break buildcycle
* Sat Aug 11 2007 dmueller@suse.de
- install Qt4 version of libraries
- build python bindings
- rename package to comply to Shared Library Policy
* Mon Aug  6 2007 dmueller@suse.de
- update to 1.73 (scintilla 2.1) (#297650)
  * A revised API, incompatible with QScintilla v1.
  * Hugely improved autocompletion and call tips support.
  * Supports both Qt v3 and Qt v4.
  * Includes Python bindings.
* Mon Jun  5 2006 stbinner@suse.de
- fix build for < 10.1
* Wed May 17 2006 dmueller@suse.de
- split into devel package (#165234)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 19 2005 joe@suse.de
- update to version 1.6 (Scintilla 1.65 based)
* Wed Sep 29 2004 joe@suse.de
- update to version 1.4 (Scintilla 1.61 based); if I don't get
  it wrong the naming scheme used by SUSE has been wrong, with
  Scintilla and qscintilla versions being mixed up.
* Tue May 11 2004 adrian@suse.de
- update to version 1.60 (Scintilla 1.3 based)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Sun Aug 17 2003 adrian@suse.de
- update to version 1.54 (Scintilla 1.2 based now)
* Wed May 28 2003 adrian@suse.de
- fix symlink
* Mon May 26 2003 adrian@suse.de
- update to version 1.53 (Scintilla 1.1 based now)
* Fri May 23 2003 adrian@suse.de
- fix symlink
* Fri May  2 2003 adrian@suse.de
- update to version 1.52
* Mon Mar 10 2003 ro@suse.de
- fix build on lib64 for real
* Mon Feb 24 2003 ro@suse.de
- fix lib64 issue
* Thu Jan 30 2003 adrian@suse.de
- initial package, version 1.49
